import DefaultLayout from "@/layouts/DefaultLayout/DefaultLayout";
import React from "react";
import { NextSeo } from "next-seo";
import StaticContentList from "@/components/StaticContentList/StaticContentList";
import { fetchPosts } from "@/services/content-service";
import { FailedFetchPostsError } from "@/errors";

export const getStaticProps = async () => {
  const res = await fetchPosts(["title", "date_published", "slug"], {
    status: "published",
  });

  if (!res.ok) {
    throw new FailedFetchPostsError(await res.text());
  }

  const json = await res.json();

  const posts = json.data.sort(
    (a, b) =>
      new Date(b.datePublished).getTime() - new Date(a.datePublished).getTime(),
  );

  return {
    props: {
      posts,
    },
    revalidate: 60,
  };
};

export const Title = "Writing";

export default function Writing({ posts }) {
  return (
    <DefaultLayout>
      <NextSeo
        title={Title}
        openGraph={{
          title: Title,
        }}
      />
      <h1>{Title}</h1>

      <section>
        <StaticContentList entries={posts} urlPrefix="writing/" />
      </section>
    </DefaultLayout>
  );
}
